#ifndef __BONOBO_CALCULATOR_CONTROL_H__
#define __BONOBO_CALCULATOR_CONTROL_H__

BonoboObject *bonobo_calculator_control_new (void);

#endif /* __BONOBO_CALCULATOR_CONTROL_H__ */
